@@ -3,9 +3,25 @@ use strict;
 use SVK::Version;  our $VERSION = $SVK::VERSION;
 
 # Load classes on demand.
-use Class::Autouse qw(:superloader);
+use Class::Autouse qw(SVK::Command);
 
 use SVN::Core;
+BEGIN {
+    # autouse hates Devel::DProf. If we're running with DProf,
+    # we need to emasculate autouse by blowing a new import sub into its
+    # package at runtime.
+    if($main::INC{'Devel/DProf.pm'})  {
+	no strict 'refs';
+	$main::INC{'autouse.pm'} = __FILE__;
+	*{'autouse::import'} = sub {
+	    require UNIVERSAL::require;
+	    shift; # get rid of $CLASS
+	    my $class = shift;
+	    $class->require or die $!;
+	    $class->export_to_level(1, undef, @_);
+        }
+    }
+}
 
 sub import {
     return unless ref ($_[0]);
@@ -29,13 +45,14 @@ sub AUTOLOAD {
     no warnings 'redefine';
     *$cmd = sub {
         my $self = shift;
-        my ($buf, $output) = ('');
+        my ($buf, $output, $ret) = ('');
         open $output, '>', \$buf if $self->{output};
-        eval { SVK::Command->invoke ($self->{xd}, $cmd, $output, @_) };
+        eval { $ret = SVK::Command->invoke ($self->{xd}, $cmd, $output, @_) };
         if ($output) {
             close $output;
             ${$self->{output}} = $buf;
         }
+        return $ret;
     };
     goto &$cmd;
 }
